#!/usr/bin/env ruby
=begin
/****************************************************************************
** $Id: rubyedit2.rb,v 1.1.1.1 2002/12/22 14:19:55 taka-hr Exp $
**
** Copyright (C) 1992-1998 Troll Tech AS.  All rights reserved.
**
** This file is part of an example program for Qt.  This example
** program may be used, distributed and modified without limitation.
**
*****************************************************************************/
=end
#SETTINGS
#Where tool bar pixmaps are
$PIXDIR = ".//"

require "qte"
include Qte
require "qpe"
include Qpe

require "rubyedit2_lib.rb"


    a = QPEApplication.new([$0] + ARGV)
    linNum = 0
    for i in 0..(ARGV.size - 1)
       if ARGV[i][0].chr == "-"
          # Process options
       elsif ARGV[i][0].chr == "+"
         linNum = ARGV[i].to_i
       else
         fname = ARGV[i]
       end
    end
    mw = REditorWindow.new
    mw.setCaption( "Document 1" )
    mw.resize(400,300)
    a.showMainWidget(mw)
    Qte::connect( a, QSIGNAL("lastWindowClosed()"), a, QSLOT("quit()") )
    if(!fname.nil?)
      mw.loadFile (fname)
    end
    if(linNum != 0)
      mw.gotoLine(linNum - 1)
    end
    a.exec
